@@ -17,6 +17,7 @@
 
 #include "mol_config.h"
 
+#include "byteorder.h"
 #include <sys/time.h>
 #include <sys/resource.h>
 #include <sys/uio.h>
@@ -30,6 +31,11 @@
 #include "booter.h"
 #include "driver_mgr.h"
 
+/* Disk Type Includes */
+#include "blk_raw.h"
+#include "blk_qcow.h"
+#include "blk_dmg.h"
+
 #define BLKFLSBUF  _IO(0x12,97)		/* from <linux/fs.h> */
 
 /* Volumes smaller than this must be specified explicitely
@@ -37,7 +43,7 @@
  * The purpose of this is preventing any boot-strap partitions
  * from beeing mounted (and hence deblessed) in MacOS.
  */
-#define BOOTSTRAP_SIZE_MB	20
+#define BOOTSTRAP_SIZE_KB	20 * 1024
 
 static opt_entry_t blk_opts[] = {
 	{"-ro",			0 },
@@ -57,11 +63,16 @@ static opt_entry_t blk_opts[] = {
 
 enum { kMacVolumes, kLinuxDisks };
 
-#define kDiskTypeUnknown	1
-#define kDiskTypeHFSPlus	2
-#define kDiskTypeHFS		4
-#define kDiskTypeUFS		8
-#define kDiskTypePartitioned	16
+#define kDiskTypeUnknown	(1<<0)
+#define kDiskTypeHFSPlus	(1<<1)
+#define kDiskTypeHFS		(1<<2)
+#define kDiskTypeHFSX		(1<<3)
+#define kDiskTypeUFS		(1<<4)
+#define kDiskTypePartitioned	(1<<5)
+#define kDiskTypeRaw		(1<<6)
+#define kDiskTypeQCow		(1<<7)
+#define kDiskTypeDMG		(1<<8)
+
 
 static bdev_desc_t 		*s_all_disks;
 
@@ -70,36 +81,84 @@ static bdev_desc_t 		*s_all_disks;
 /*	misc								*/
 /************************************************************************/
 
-/* volname is allocated */
 static int
-inspect_disk( int fd, char **type, char **volname )
+find_disk_type(int fd, char *name, bdev_desc_t *bdev)
 {
 	char buf[512];
+	/* Always open as a RAW disk to ensure that read/write/seek are valid */
+	raw_open(fd, bdev);	
+
+	/* If we can't read 512 bytes, give up */
+	if ( pread(fd, buf, 512, 0) != 512 ) 
+		return kDiskTypeUnknown;
+
+	/* Force handling driver disks as RAW disks */
+	if (!strncmp(name, "images/moldisk.dmg", 18) ||
+	    !strncmp(name, "images/moldiskX.dmg", 19)) 
+		return kDiskTypeRaw;
+	
+	/* Check for QCow Disks */
+	if ( QCOW_MAGIC == be32_to_cpu(((QCowHeader *)buf)->magic) ) {
+		qcow_open(fd, bdev);
+		return kDiskTypeQCow;
+	}
+
+	/* Check for dmg disks */
+	if (strlen(name) > 4 && !strncmp(name + strlen(name) - 4, ".dmg", 4)) {
+		dmg_open(fd, bdev);
+		return kDiskTypeDMG;		
+	}
+
+	/* Otherwise, guess it's a raw disk */
+	return kDiskTypeRaw;
+}
+
+/* volname is allocated */
+static int
+inspect_disk( bdev_desc_t *bdev, char **typestr, char **volname, int type)
+{
+	struct iovec vec;
+	char buf[512];
+	vec.iov_base = buf;
+	vec.iov_len = 512;
 	desc_map_t *dmap = (desc_map_t*)buf;
 	hfs_mdb_t *mdb = (hfs_mdb_t*)buf;
 	int signature;
 
-	*type = "Disk";
-	*volname = NULL;
+	*typestr = "Disk";
+	*volname = NULL;	
 
-	if( pread(fd, buf, 512, 0) != 512 )
+	if (type == kDiskTypeUnknown) {
+		*volname = strdup("- Unknown -");
 		return kDiskTypeUnknown;
-	
+	}
+
+	/* Read the first 512 bytes of the disk for identification */
+	bdev->seek(bdev, 0, 0);
+	if( bdev->read(bdev, &vec, 1) != 512 ) 
+		return kDiskTypeUnknown;
+
 	if( dmap->sbSig == DESC_MAP_SIGNATURE ) {
 		*volname = strdup("- Partioned -");
 		return kDiskTypePartitioned;
 	}
 
-	if( pread(fd, buf, 512, 2*512) != 512 )
+	bdev->seek(bdev, 2, 0);
+	if( bdev->read(bdev, &vec, 1) != 512 ) 
 		return kDiskTypeUnknown;
-	
+
 	signature = hfs_get_ushort(mdb->drSigWord);
 
 	if( signature == HFS_PLUS_SIGNATURE ) {
-		*type = "Unembedded HFS+";
+		*typestr = "Unembedded HFS+";
 		return kDiskTypeHFSPlus;
 	}
 
+	if( signature == HFSX_SIGNATURE ) {
+		*typestr = "HFSX";
+		return kDiskTypeHFSX;
+	}
+
 	if( signature == HFS_SIGNATURE ) {
 		char vname[256];
 		memcpy( vname, &mdb->drVN[1], mdb->drVN[0] );
@@ -107,10 +166,10 @@ inspect_disk( int fd, char **type, char **volname )
 		*volname = strdup( vname );
 
 		if( hfs_get_ushort(mdb->drEmbedSigWord) == HFS_PLUS_SIGNATURE ) {
-			*type = "HFS+";
+			*typestr = "HFS+";
 			return kDiskTypeHFSPlus;
 		}
-		*type = "HFS";
+		*typestr = "HFS";
 		return kDiskTypeHFS;
 	}
 	return kDiskTypeUnknown;
@@ -146,17 +205,22 @@ report_disk_export( bdev_desc_t *bd, const char *type )
 }
 
 static void
-register_disk( const char *typestr, const char *name, const char *vol_name, int fd, long flags, ulong num_blocks )
+register_disk(bdev_desc_t *bdev, const char *typestr, const char *name,
+	      const char *vol_name, int fd, long flags, ulong blocks )
 {
-	bdev_desc_t *bdev = malloc( sizeof(bdev_desc_t) );
-	CLEAR( *bdev );
+	if(NULL == bdev) {
+		bdev = malloc( sizeof(bdev_desc_t) );
+		CLEAR( *bdev );
+		/* If bdev isn't allocated already, open as raw disk */
+		raw_open(fd, bdev);
+	}
 
 	bdev->dev_name = strdup(name);
 	bdev->vol_name = vol_name ? strdup(vol_name) : NULL;
 
 	bdev->fd = fd;
-	bdev->flags = flags;
-	bdev->size = 512ULL * num_blocks;
+	bdev->flags |= flags;
+	bdev->size = 512ULL * blocks;
 
 	bdev->priv_next = s_all_disks;
 	s_all_disks = bdev;
@@ -172,23 +236,38 @@ register_disk( const char *typestr, const char *name, const char *vol_name, int
 static int
 open_mac_disk( char *name, int flags, int constructed )
 {
+	bdev_desc_t *bdev;
 	int type, fd, ro_fallback, ret=0;
 	char *volname, *typestr;
-	uint size;
 	
 	if( (fd=disk_open(name, flags, &ro_fallback, constructed)) < 0 )
 		return -1;
-	type = inspect_disk( fd, &typestr, &volname );
 
+	/* Alloc the block device */
+	bdev = (bdev_desc_t *)malloc( sizeof(bdev_desc_t) );
+	if(!bdev) {
+		close(fd);
+		return -1;
+	}
+	CLEAR( *bdev );
+
+	/* Finds disk type and performs init for bdev pointers */
+	type = find_disk_type(fd, name, bdev);
+	
+	/* Inspect the disk to ensure it's valid */
+	type |= inspect_disk(bdev, &typestr, &volname, type);
+	
 	if( ro_fallback )
 		flags &= ~BF_ENABLE_WRITE;
 
-	if( type & (kDiskTypeHFSPlus | kDiskTypeHFS | kDiskTypeUFS) ) {
-		/* standard mac volumes */
-	} else if( type & kDiskTypePartitioned ) {
+	if( type & (kDiskTypeHFSPlus | kDiskTypeHFSX | kDiskTypeHFS | kDiskTypeUFS) ) {
+		/* Standard Mac Volumes, nothing to do  */
+	} 
+	else if( type & kDiskTypePartitioned ) {
 		if( constructed )
 			ret = -1;
-	} else {
+	}
+	else {
 		/* unknown disk type */
 		if( !(flags & BF_FORCE) ) {
 			if( !constructed )
@@ -196,21 +275,26 @@ open_mac_disk( char *name, int flags, int constructed )
 			ret = -1;
 		}
 	}
-	size = get_file_size_in_blks(fd);
 
 	/* detect boot-strap partitions by the small size */
 	if( (flags & BF_ENABLE_WRITE) && (type & (kDiskTypeHFSPlus | kDiskTypeHFS)) ) {
 
-		if( size/2048 < BOOTSTRAP_SIZE_MB && !(flags & BF_FORCE) ) {
+		if( bdev->size/1024 < BOOTSTRAP_SIZE_KB && !(flags & BF_FORCE) ) {
 			printm("----> %s might be a boot-strap partition.\n", name );
 			ret = -1;
 		}
 	}
 
-	if( !ret )
-		register_disk( typestr, name, volname, fd, flags, get_file_size_in_blks(fd) );
-	else
-		close( fd );
+	if( !ret ) {
+		/* Register the disk with MOL */
+		register_disk( bdev, typestr, name, volname, bdev->fd, flags, bdev->size / 512ULL );
+	}
+	else {
+		/* Close the block device */
+		close( bdev->fd );
+		/* Free the block dev struct */
+		free(bdev);
+	}
 
 	if( volname )
 		free( volname );
@@ -224,7 +308,7 @@ setup_mac_disk( char *name, int flags )
 	char buf[32], **pp;
 	int i, n;
 	
-	/* /dev/hda type device? Substitute with /dev/hdaX */
+	/* Check for entire device (/dev/hda) and substitute with /dev/hdaX */
 	for( pp=dev_list; !(flags & BF_WHOLE_DISK) && *pp; pp++ ) {
 		if( strncmp(*pp, name, strlen(*pp)) || strlen(name) != strlen(*pp)+1 )
 			continue;
@@ -243,6 +327,18 @@ setup_mac_disk( char *name, int flags )
 }
 
 
+static void
+setup_linux_disk( char *name, int flags )
+{
+	int fd, ro_fallback=0;
+	printm("FIXME: non RAW disks won't work with Linux yet!\n");
+	if( (fd=disk_open( name, flags, &ro_fallback, 0 )) >= 0 ) {
+		if( ro_fallback )
+			flags &= ~BF_ENABLE_WRITE;
+		register_disk(NULL, "Disk", name, NULL, fd, flags, get_file_size_in_blks(fd) );
+	}
+}
+	
 /************************************************************************/
 /*	setup disks							*/
 /************************************************************************/
@@ -265,7 +361,7 @@ setup_disks( char *res_name, int type )
 			flags &= ~BF_ENABLE_WRITE;
 			if( (fd=disk_open( name, flags, &ro_fallback, 0 )) < 0 )
 				continue;
-			register_disk( "CD", name, "CD/DVD", fd, flags, 0 );
+			register_disk(NULL, "CD", name, "CD/DVD", fd, flags, 0 );
 			continue;
 		}
 
@@ -275,11 +371,7 @@ setup_disks( char *res_name, int type )
 			break;
 
 		case kLinuxDisks:
-			if( (fd=disk_open( name, flags, &ro_fallback, 0 )) >= 0 ) {
-				if( ro_fallback )
-					flags &= ~BF_ENABLE_WRITE;
-				register_disk( "Disk", name, NULL, fd, flags, get_file_size_in_blks(fd) );
-			}
+			setup_linux_disk( name, flags );
 			break;
 		}
 	}
@@ -293,75 +385,6 @@ setup_disks( char *res_name, int type )
 			bdev->flags &= ~BF_BOOT;
 }
 
-
-
-/************************************************************************/
-/*	checksum calculations						*/
-/************************************************************************/
-
-#if 0
-/* Calculate a checksum for the HFS(+) MDB (master directory block). 
- * In particular, the modification date is included in the checksum.
- */
-static int 
-get_hfs_checksum( drive_t *drv, ulong *checksum )
-{
-	hfs_plus_mdb_t mdb_plus;
-	hfs_mdb_t mdb;
-	ulong val=0;
-
-	blk_lseek( drv->fd, 2, SEEK_SET );
-	read( drv->fd, &mdb, sizeof(mdb) );
-	if( hfs_get_ushort(mdb.drSigWord) != HFS_SIGNATURE )
-		return -1;
-
-	/* printm("HFS volume detected\n"); */
-
-	if( hfs_get_ushort(mdb.drEmbedSigWord) == HFS_PLUS_SIGNATURE ) {
-		int sblock = hfs_get_ushort(mdb.drAlBlSt);
-		sblock += (hfs_get_uint(mdb.drAlBlkSiz) / 512) * (hfs_get_uint(mdb.drEmbedExtent) >> 16);
-
-		blk_lseek( drv->fd, sblock + 2, SEEK_SET );
-		read( drv->fd, &mdb_plus, sizeof(mdb_plus) );
-
-		if( mdb_plus.signature != HFS_PLUS_SIGNATURE ) {
-			printm("HFS_PLUS_SIGNATURE expected\n");
-			return -1;
-		}
-		val += calc_checksum( (char*)&mdb_plus, sizeof(mdb_plus) );
-
-		/* printm("HFS+ volume detected\n"); */
-	}
-	val += calc_checksum( (char*)&mdb, sizeof(mdb_plus) );
-	*checksum = val;
-
-	/* printm("HFS-MDB checksum %08lX\n", *checksum ); */
-	return 0;
-}
-
-static int
-get_mdb_checksum( drive_t *drv, ulong *checksum )
-{
-	char buf[2048];
-
-	if( !get_hfs_checksum( drv, checksum ) )
-		return 0;
-
-	if( !drv->locked || !(drv->flags & bf_force) ) {
-		printm("Save session does not support r/w volumes which are not HFS(+)\n");
-		return 1;
-	}
-
-	/* fallback - read the first four sectors */
-	blk_lseek( drv->fd, 0, SEEK_SET );
-	read( drv->fd, &buf, sizeof(buf) );
-
-	*checksum = calc_checksum( buf, sizeof(buf) );
-	return 0;
-}
-#endif
-
-
 /************************************************************************/
 /*	Global interface						*/
 /************************************************************************/
@@ -399,6 +422,9 @@ bdev_close_volume( bdev_desc_t *dev )
 		free( dev->dev_name );
 		if( dev->vol_name )
 			free( dev->vol_name );
+
+		if( dev->close != NULL)
+			dev->close(dev);
 		
 		if( dev->fd != -1 ) {
 			/* XXX: the ioctl should only be done for block devices! */
@@ -414,7 +440,7 @@ bdev_close_volume( bdev_desc_t *dev )
 static int
 blkdev_init( void )
 {
-	printm("\n");
+	printm("\nAvailable Disks:\n");
 	if( is_classic_boot() || is_osx_boot() ) {
 		setup_disks("blkdev_mol", kMacVolumes );
 		setup_disks("blkdev", kMacVolumes );
