@@ -31,6 +31,8 @@ enum {
 	BF_REMOVABLE		= 512,
 
 	BF_DRV_DISK		= 1024,
+
+	BF_ENCRYPTED		= 2048,
 };
 
 /* from disk_open.c */
@@ -49,6 +51,15 @@ typedef struct bdev_desc {
 	ulong			mdb_checksum;
 	ulong			name_checksum;
 
+	int 			(*read)();		/* Read from disk image */
+	int 			(*write)();		/* Write to disk image */
+	int 			(*seek)();		/* Seek in disk image */
+	int			(*real_read)();		/* Read to use if wrapped */
+	int			(*real_write)();	/* Write to use if wrapped */
+	void			(*close)();		/* Close device */
+
+	void 			* priv;		/* Driver specific private structures */
+
 	/* fields private to blkdev.c */
 	int			priv_claimed;
 	struct bdev_desc	*priv_next;
@@ -58,7 +69,7 @@ extern void 		bdev_setup_drives( void );
 
 extern bdev_desc_t	*bdev_get_next_volume( bdev_desc_t *last );
 extern void		bdev_claim_volume( bdev_desc_t *bdev );
-extern void		bdev_close_volume( bdev_desc_t *dev );
+extern void		bdev_close_volume( bdev_desc_t *bdev );
 
 extern int		reserve_scsidev( int host, int channel, int unit_id );
 
