@@ -21,16 +21,11 @@
 #ifndef __H_MOL_DRIVER_MGR__
 #define	__H_MOL_DRIVER_MGR__
 
-typedef struct
-{
-	char	name[64];
-	int	(*init)(void);
-	void	(*cleanup)(void);
+typedef struct {
+	const char	*name;
+	int		(*init)(void);
+	void		(*cleanup)(void);
 } driver_interface_t;
 
 
-int driver_mgr_init(void);
-int driver_mgr_cleanup(void);
-
-
 #endif /* __H_MOL_DRIVER_MGR__ */
