@@ -16,7 +16,7 @@
 
 #include "mol_config.h"
 #include <sys/uio.h>
-#include "poll.h"
+#include "poll_compat.h"
 //#include "verbose.h"
 #include "os_interface.h"
 #include "osi_driver.h"
@@ -477,7 +477,7 @@ mac_enet_init( void )
 		memset( is, 0, sizeof(*is) );		
 
 		if( find_packet_driver(i, &is->iface) )
-			continue;
+			break;
 		add_netdev( is );
 	}
 	if( !numifs )
