@@ -18,6 +18,15 @@
 
 #include "sound_sh.h"
 
+#define SND_DEBUG 0
+#if SND_DEBUG
+#define DEBUG_SND \
+	if (0) {} else printm
+#else
+#define DEBUG_SND \
+	if (1) {} else printm
+#endif /* SND_DEBUG */
+
 typedef struct {
 	void	(*cleanup)( void );
 
@@ -44,4 +53,7 @@ extern sound_ops_t 		*alsa_probe( int exact );
 static inline sound_ops_t	*alsa_probe( int exact ) { return NULL; }
 #endif
 
+/* We always build the no sound plugin */
+extern sound_ops_t		*nosound_prove(int exact);
+
 #endif   /* _H_SOUND_IFACE */
