@@ -269,7 +269,7 @@ static void
 put_ed( int mphys, ohci_ed_t *dest )
 {
 	ulong *d = (ulong*)transl_mphys(mphys);
-	u32 *s = (int*)dest;
+	u32 *s = (u32 *)dest;
 	if( d ) {
 		st_le32(d, s[0]);
 		st_le32(d+1, s[1]);
@@ -466,10 +466,18 @@ complete_urb_( priv_urb_t *u, int status )
 
 	unlink_urb( u );
 
+	union {
+		u32 * e;
+		ulong * l;
+	}nexted;
+
 	/* verify that the urb is still hot (i.e. on the lists) */
-	for( _ed=NULL; mphys && mphys != u->ed_mphys; mphys=ld_le32((ulong*)&_ed->nexted) )
+	for( _ed=NULL; mphys && mphys != u->ed_mphys; ) {
 		if( !(_ed=transl_mphys(mphys)) )
 			break;
+		nexted.e = &(_ed->nexted);
+		mphys = ld_le32(nexted.l);
+	}
 	if( !mphys || !(_ed=transl_mphys(mphys)) )
 		goto bad;
 	get_ed( &ed, mphys );
@@ -490,7 +498,7 @@ complete_urb_( priv_urb_t *u, int status )
 	/* copy data from urb buffer */
 	if( status == CC_NOERROR ) {
 		if( u->uurb.is_read && u->uurb.actcount )
-			put_td_data( &td, u->uurb.buf, u->uurb.actcount );
+			put_td_data( &td, (char *)u->uurb.buf, u->uurb.actcount );
 
 		/* update td fields */
 		if( u->uurb.actcount == u->uurb.size ) {
@@ -616,7 +624,7 @@ finish_ctrl_urb( priv_ctrl_urb_t *cu, priv_urb_t *u )
 static int
 hook_ctrl_urb_write( priv_ctrl_urb_t *cu, priv_urb_t *u )
 {
-	char *p = cu->ucurb.buf;
+	char *p = (char *)cu->ucurb.buf;
 	usb_device_t *dev;
 	int fa;
 	
@@ -653,7 +661,7 @@ do_submit_ctrl( priv_urb_t *u, int dir )
 	}
 	/* SETUP transaction */
 	if( !cu ) {
-		char *p = u->uurb.buf;
+		char *p = (char *)u->uurb.buf;
 		int size, is_read;
 
 		if( dir != kDirSETUP ) {
@@ -798,7 +806,7 @@ process_endpoint( ohci_ed_t *ed, int ed_mphys, int list_type )
 	u->uurb.is_read = (dir == kDirIN);
 
 	if( !u->uurb.is_read && size )
-		get_td_data( u->uurb.buf, &td, size );
+		get_td_data( (char *) u->uurb.buf, &td, size );
 
 	u->next = hc.urbs;
 	hc.urbs = u;
@@ -912,6 +920,11 @@ clean_stale_interrupt_urbs( void )
 	priv_urb_t *u;
 	ohci_ed_t *_ed;
 	int mphys;
+	
+	union {
+		u32 * e;
+		ulong * l;
+	}nexted;
 
 	if( !(hc.r[HC_CONTROL] & CTRL_PLE) )
 		return;
@@ -921,9 +934,12 @@ clean_stale_interrupt_urbs( void )
 			continue;
 
 		mphys = get_list_head( u->list_type );
-		for( _ed=NULL; mphys && mphys != u->ed_mphys; mphys=ld_le32((ulong*)&_ed->nexted) )
+		for( _ed=NULL; mphys && mphys != u->ed_mphys;){
 			if( !(_ed=transl_mphys(mphys)) )
 				break;
+			nexted.e = &(_ed->nexted);
+			mphys = ld_le32(nexted.l);
+		}
 
 		if( mphys != u->ed_mphys ) {
 			static int once=0;
