@@ -23,9 +23,8 @@
 #include <signal.h>
 #include <sys/ioctl.h>
 #include <dirent.h>
-#include <linux/compiler.h>				/* linux/usbdevice_fs.h breaks otherwise */
 #include <linux/usbdevice_fs.h>
-#include "poll.h"
+#include "poll_compat.h"
 #include "async.h"
 #include "byteorder.h"
 #include "timer.h"
