@@ -69,7 +69,7 @@
 #include <netdb.h>
 #include <fcntl.h>
 #include <sys/socket.h>
-#include "poll.h"
+#include "poll_compat.h"
 
 #include "verbose.h"
 #include "debugger.h"
@@ -706,7 +706,8 @@ vnc_thread( void *arg )
 			if( !read_exact(((unsigned char *)&request) + 1,
 					sz_rfbFramebufferUpdateRequestMsg - 1) < 0 )
 				goto endo;
-
+			if (!request.incremental)
+				force_redraw = true;
 			request_received = true;
 			//send_update();
 			break;
@@ -1163,7 +1164,7 @@ ks_decode( CARD32 ks )
 	case XK_9: case XK_parenleft: return 0x19;
 	case XK_0: case XK_parenright: return 0x1d;
  
-	case XK_grave: case XK_asciitilde: return 0x0a;
+	case XK_grave: case XK_asciitilde: return 0x32;
 	case XK_minus: case XK_underscore: return 0x1b;
 	case XK_equal: case XK_plus: return 0x18;
 	case XK_bracketleft:
