@@ -1,12 +1,12 @@
 /* 
  *   Creation Date: <2002/04/14 13:48:54 samuel>
- *   Time-stamp: <2003/06/12 14:08:25 samuel>
+ *   Time-stamp: <2004/02/07 17:55:44 samuel>
  *   
  *	<keyremap.c>
  *	
  *	
  *   
- *   Copyright (C) 2002, 2003 Samuel Rydh (samuel@ibrium.se)
+ *   Copyright (C) 2002, 2003, 2004 Samuel Rydh (samuel@ibrium.se)
  *   
  *   This program is free software; you can redistribute it and/or
  *   modify it under the terms of the GNU General Public License
@@ -18,7 +18,7 @@
 #include <stdarg.h>
 #include "os_interface.h"
 #include "osi_calls.h"
-#include "keycodes.h"
+#include "kbd_sh.h"
 #include "video_sh.h"
 
 #include "font_8x8.c"
@@ -333,7 +333,7 @@ draw_pixel( int x, int y, int col )
 static void
 draw_char( char ch, int h, int v )
 {
-	char *c = fontdata;
+	char *c = (char *)fontdata;
 	int x, y, xx, rskip, m;
 
 	while( h >= tc.vmode.w/FONT_WIDTH || v >= tc.vmode.h/FONT_ADJ_HEIGHT )
