@@ -119,7 +119,11 @@ demasquerade( struct sk_buff *skb, struct SheepVars *v )
 {
 	const char *local_addr = v->ether->dev_addr;
 	const char *fake_addr = v->fake_addr;
+#if (LINUX_VERSION_CODE > KERNEL_VERSION(2,6,21))
+	char *p = skb_mac_header(skb);
+#else
 	char *p = skb->mac.raw;
+#endif
 	int proto = *(short*)&p[12];
 	
 	cpyaddr( &p[6], local_addr );		// Source address
@@ -211,7 +215,11 @@ sheep_net_receiver( struct sk_buff *skb, struct net_device *dev, struct packet_t
 			// filter IP-traffic
 			if( (skb->protocol == htons(ETH_P_IP)) ) {
 				// drop if not addreesed to MOL?
+#if (LINUX_VERSION_CODE > KERNEL_VERSION(2,6,21))
+				if( !v->ipfilter || (ipip_hdr(skb)->daddr != v->ipfilter) )
+#else
 				if( !v->ipfilter || (skb->h.ipiph->daddr != v->ipfilter) )
+#endif
 					goto drop;
 				// we don't want this packet interpreted by linux...
 				skb->protocol = PROT_MAGIC;
@@ -236,7 +244,11 @@ sheep_net_receiver( struct sk_buff *skb, struct net_device *dev, struct packet_t
 		cpyaddr( &ETH_HDR(skb)->h_dest[0], v->fake_addr );
 
 	// We also want the Ethernet header
+#if (LINUX_VERSION_CODE > KERNEL_VERSION(2,6,21))
+	skb_push( skb, skb->data - skb_mac_header(skb) );
+#else
 	skb_push( skb, skb->data - skb->mac.raw );
+#endif
 
 	// Enqueue packet
 	skb_queue_tail( &v->queue, skb );
@@ -368,8 +380,14 @@ memcpy_fromv( char *buf, const struct iovec *iv, int s )
 }
 
 static ssize_t 
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,19)
+sheep_net_aio_read(struct kiocb *iocb, const struct iovec *iv, unsigned long count, loff_t pos)
+{
+	struct file *f = iocb->ki_filp;
+#else /* Linux 2.6.18 or older */
 sheep_net_readv( struct file *f, const struct iovec *iv, unsigned long count, loff_t *pos )
 {
+#endif
 	struct SheepVars *v = (struct SheepVars *)f->private_data;
 	struct sk_buff *skb;
 	int size = get_iovsize( iv, count );
@@ -398,8 +416,14 @@ sheep_net_readv( struct file *f, const struct iovec *iv, unsigned long count, lo
 }
 
 static ssize_t 
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,19)
+sheep_net_aio_write(struct kiocb *iocb, const struct iovec *iv, unsigned long count, loff_t off)
+{
+	struct file *f = iocb->ki_filp;
+#else /* Linux 2.6.18 or older */
 sheep_net_writev( struct file *f, const struct iovec *iv, unsigned long count, loff_t *off )
 {
+#endif
 	struct SheepVars *v = (struct SheepVars *)f->private_data;
 	struct sk_buff *skb;
 	int size = get_iovsize( iv, count );
@@ -435,8 +459,14 @@ sheep_net_writev( struct file *f, const struct iovec *iv, unsigned long count, l
 	skb->sk = v->skt;
 	skb->dev = v->ether;
 	skb->priority = 0;
+#if (LINUX_VERSION_CODE > KERNEL_VERSION(2,6,21))
+	skb_set_network_header(skb, v->ether->hard_header_len);
+	skb_set_transport_header(skb, v->ether->hard_header_len);
+	skb_reset_mac_header(skb);
+#else
 	skb->nh.raw = skb->h.raw = skb->data + v->ether->hard_header_len;
 	skb->mac.raw = skb->data;
+#endif
 
 	// Base the IP-filter on the IP address of outgoing ARPs
 	if( ETH_HDR(skb)->h_proto == htons(ETH_P_ARP) ) {
@@ -471,6 +501,8 @@ sheep_net_writev( struct file *f, const struct iovec *iv, unsigned long count, l
 	return size;
 }
 
+/* We take care of this using do_sync_* instead in 2.6.19 and newer */
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,19)
 static ssize_t
 sheep_net_read( struct file *f, char *buf, size_t count, loff_t *off )
 {
@@ -488,6 +520,7 @@ sheep_net_write( struct file *f, const char *buf, size_t count, loff_t *off )
 	iv.iov_base = (char *)buf;
 	return sheep_net_writev( f, &iv, 1, off );
 }
+#endif
 
 static unsigned int
 sheep_net_poll( struct file *f, struct poll_table_struct *wait )
@@ -623,6 +656,19 @@ error:
 /*	init / cleanup							*/
 /************************************************************************/
 
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,19)
+static struct file_operations sheep_net_fops = {
+	.owner		= THIS_MODULE,
+	.read		= do_sync_read,
+	.aio_read	= sheep_net_aio_read,
+	.write		= do_sync_write,
+	.aio_write	= sheep_net_aio_write,
+	.poll		= sheep_net_poll,
+	.ioctl		= sheep_net_ioctl,
+	.open		= sheep_net_open,
+	.release	= sheep_net_release,
+};
+#else
 static struct file_operations sheep_net_fops = {
 	.owner		= THIS_MODULE,
 	.read		= sheep_net_read,
@@ -634,6 +680,7 @@ static struct file_operations sheep_net_fops = {
 	.open		= sheep_net_open,
 	.release	= sheep_net_release,
 };
+#endif
 
 static struct miscdevice sheep_net_device = {
 	.minor		= SHEEP_NET_MINOR,
