@@ -448,9 +448,9 @@ test_pattern( struct fb_var_screeninfo *var, struct fb_fix_screeninfo *fix, int
 	/* palette */
 	cmap.len = 256;
 	ctable = (short*)calloc( cmap.len * 3, sizeof(short) );
-	cmap.red = &ctable[0];
-	cmap.green = &ctable[256];
-	cmap.blue = &ctable[512];
+	cmap.red = (unsigned short *)&ctable[0];
+	cmap.green = (unsigned short *)&ctable[256];
+	cmap.blue = (unsigned short *)&ctable[512];
 	cmap.transp = NULL;
 	cmap.start = 0;
 
